@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AdminTemplateAttachment.pm - to add/update/delete groups <-> users
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -89,7 +90,7 @@ sub Run {
                     ID => $StandardTemplateID
                 );
                 $StandardTemplateData{$StandardTemplateID}
-                    = $Self->{LayoutObject}->{LanguageObject}->Get( $Data{TemplateType} )
+                    = $Self->{LayoutObject}->{LanguageObject}->Translate( $Data{TemplateType} )
                     . ' - '
                     . $Data{Name};
             }
@@ -275,7 +276,7 @@ sub _Overview {
                 ID => $StandardTemplateID
             );
             $StandardTemplateData{$StandardTemplateID}
-                = $Self->{LayoutObject}->{LanguageObject}->Get( $Data{TemplateType} )
+                = $Self->{LayoutObject}->{LanguageObject}->Translate( $Data{TemplateType} )
                 . ' - '
                 . $Data{Name};
         }
