@@ -1,8 +1,6 @@
 # --
 # Kernel/System/PostMaster/Filter/NewTicketReject.pm - sub part of PostMaster.pm
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-# --
-# $Id: NewTicketReject.pm,v 1.14.4.1 2011-11-05 19:17:21 mb Exp $
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,11 +12,12 @@ package Kernel::System::PostMaster::Filter::NewTicketReject;
 use strict;
 use warnings;
 
-use Kernel::System::Ticket;
-use Kernel::System::Email;
-
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.14.4.1 $) [1];
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Email',
+    'Kernel::System::Log',
+    'Kernel::System::Ticket',
+);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -29,14 +28,6 @@ sub new {
 
     $Self->{Debug} = $Param{Debug} || 0;
 
-    # get needed objects
-    for (qw(ConfigObject LogObject DBObject MainObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
-
-    $Self->{TicketObject} = Kernel::System::Ticket->new(%Param);
-    $Self->{EmailObject}  = Kernel::System::Email->new(%Param);
-
     return $Self;
 }
 
@@ -46,7 +37,10 @@ sub Run {
     # check needed stuff
     for (qw(JobConfig GetParam)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -69,10 +63,11 @@ sub Run {
     my $Matched    = '';
     my $MatchedNot = 0;
     for ( sort keys %Match ) {
+
         if ( $Param{GetParam}->{$_} && $Param{GetParam}->{$_} =~ /$Match{$_}/i ) {
             $Matched = $1 || '1';
             if ( $Self->{Debug} > 1 ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'debug',
                     Message  => "'$Param{GetParam}->{$_}' =~ /$Match{$_}/i matched!",
                 );
@@ -81,7 +76,7 @@ sub Run {
         else {
             $MatchedNot = 1;
             if ( $Self->{Debug} > 1 ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'debug',
                     Message  => "'$Param{GetParam}->{$_}' =~ /$Match{$_}/i matched NOT!",
                 );
@@ -90,36 +85,44 @@ sub Run {
     }
     if ( $Matched && !$MatchedNot ) {
 
+        # get ticket object
+        my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
         # check if new ticket
-        my $Tn = $Self->{TicketObject}->GetTNByString( $Param{GetParam}->{Subject} );
-        return 1 if $Tn && $Self->{TicketObject}->TicketCheckNumber( Tn => $Tn );
+        my $Tn = $TicketObject->GetTNByString( $Param{GetParam}->{Subject} );
+
+        return 1 if $Tn && $TicketObject->TicketCheckNumber( Tn => $Tn );
 
         # set attributes if ticket is created
-        for ( keys %Set ) {
+        for ( sort keys %Set ) {
             $Param{GetParam}->{$_} = $Set{$_};
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'notice',
                 Message =>
                     "Set param '$_' to '$Set{$_}' (Message-ID: $Param{GetParam}->{'Message-ID'}) ",
             );
         }
 
+        # get config object
+        my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
         # send bounce mail
-        my $Subject = $Self->{ConfigObject}->Get(
+        my $Subject = $ConfigObject->Get(
             'PostMaster::PreFilterModule::NewTicketReject::Subject'
         );
-        my $Body = $Self->{ConfigObject}->Get(
+        my $Body = $ConfigObject->Get(
             'PostMaster::PreFilterModule::NewTicketReject::Body'
         );
-        my $Sender = $Self->{ConfigObject}->Get(
+        my $Sender = $ConfigObject->Get(
             'PostMaster::PreFilterModule::NewTicketReject::Sender'
         ) || '';
-        $Self->{EmailObject}->Send(
+
+        $Kernel::OM->Get('Kernel::System::Email')->Send(
             From       => $Sender,
             To         => $Param{GetParam}->{From},
             Subject    => $Subject,
             Body       => $Body,
-            Charset    => $Self->{ConfigObject}->Get('DefaultCharset'),
+            Charset    => 'utf-8',
             MimeType   => 'text/plain',
             Loop       => 1,
             Attachment => [
@@ -130,12 +133,13 @@ sub Run {
                 }
             ],
         );
-        $Self->{LogObject}->Log(
+
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "Send reject mail to '$Param{GetParam}->{From}'!",
         );
-
     }
+
     return 1;
 }
 
