@@ -1,4 +1,5 @@
 # --
+# Kernel/System/Ticket/ColumnFilter.pm - all column filter functions
 # Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
@@ -10,10 +11,16 @@ package Kernel::System::Ticket::ColumnFilter;
 
 use strict;
 use warnings;
-use Kernel::System::User;
-use Kernel::System::CustomerUser;
+
 use Kernel::System::VariableCheck qw(IsArrayRefWithData IsHashRefWithData IsStringWithData);
 
+our @ObjectDependencies = (
+    'Kernel::System::DB',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::User',
+);
+
 =head1 NAME
 
 Kernel::System::Ticket::ColumnFilter - Column Filter library
@@ -30,48 +37,11 @@ All functions for Column Filters.
 
 =item new()
 
-create an object
+create an object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Time;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::Ticket::ColumnFilter;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $TicketObject = Kernel::System::Ticket::ColumnFilter->new(
-        ConfigObject       => $ConfigObject,
-        LogObject          => $LogObject,
-        DBObject           => $DBObject,
-        MainObject         => $MainObject,
-        TimeObject         => $TimeObject,
-        EncodeObject       => $EncodeObject,
-        CustomerUserObject => $CustomerUserObject, # if given
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $TicketColumnFilterObject = $Kernel::OM->Get('Kernel::System::Ticket::ColumnFilter');
 
 =cut
 
@@ -82,21 +52,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for my $Needed (qw(ConfigObject LogObject TimeObject DBObject MainObject EncodeObject)) {
-        if ( $Param{$Needed} ) {
-            $Self->{$Needed} = $Param{$Needed};
-        }
-        else {
-            die "Got no $Needed!";
-        }
-    }
-
-    # create common needed module objects
-    $Self->{UserObject} = Kernel::System::User->new( %{$Self} );
-
-    #$Self->{CustomerUserObject} = Kernel::System::CustomerUser->new( %{$Self} );
-
     return $Self;
 }
 
@@ -133,25 +88,30 @@ sub StateFilterValuesGet {
     }
 
     if ( !IsArrayRefWithData( $Param{TicketIDs} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'TicketIDs must be an array ref!',
         );
         return;
     }
 
-    my @TicketIDs = @{ $Param{TicketIDs} };
-    my $TicketIDString = join ', ', sort @TicketIDs;
+    my $TicketIDString = $Self->_TicketIDStringGet(
+        TicketIDs => $Param{TicketIDs},
+    );
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL => "SELECT DISTINCT(t.ticket_state_id), ts.name"
             . " FROM ticket t, ticket_state ts"
-            . " WHERE t.id IN ($TicketIDString) AND t.ticket_state_id = ts.id"
+            . " WHERE t.ticket_state_id = ts.id"
+            . $TicketIDString
             . " ORDER BY t.ticket_state_id DESC",
     );
 
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             $Data{ $Row[0] } = $Row[1];
         }
@@ -195,25 +155,30 @@ sub QueueFilterValuesGet {
     }
 
     if ( !IsArrayRefWithData( $Param{TicketIDs} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'TicketIDs must be an array ref!',
         );
         return;
     }
 
-    my @TicketIDs = @{ $Param{TicketIDs} };
-    my $TicketIDString = join ', ', sort @TicketIDs;
+    my $TicketIDString = $Self->_TicketIDStringGet(
+        TicketIDs => $Param{TicketIDs},
+    );
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL => "SELECT DISTINCT(t.queue_id), q.name"
             . " FROM ticket t, queue q"
-            . " WHERE t.id IN ($TicketIDString) AND t.queue_id = q.id"
+            . " WHERE t.queue_id = q.id"
+            . $TicketIDString
             . " ORDER BY t.queue_id DESC",
     );
 
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             $Data{ $Row[0] } = $Row[1];
         }
@@ -255,25 +220,30 @@ sub PriorityFilterValuesGet {
     }
 
     if ( !IsArrayRefWithData( $Param{TicketIDs} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'TicketIDs must be an array ref!',
         );
         return;
     }
 
-    my @TicketIDs = @{ $Param{TicketIDs} };
-    my $TicketIDString = join ', ', sort @TicketIDs;
+    my $TicketIDString = $Self->_TicketIDStringGet(
+        TicketIDs => $Param{TicketIDs},
+    );
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL => "SELECT DISTINCT(t.ticket_priority_id), tp.name"
             . " FROM ticket t, ticket_priority tp"
-            . " WHERE t.id IN ($TicketIDString) AND t.ticket_priority_id = tp.id"
+            . " WHERE t.ticket_priority_id = tp.id"
+            . $TicketIDString
             . " ORDER BY t.ticket_priority_id DESC",
     );
 
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             $Data{ $Row[0] } = $Row[1];
         }
@@ -315,25 +285,30 @@ sub TypeFilterValuesGet {
     }
 
     if ( !IsArrayRefWithData( $Param{TicketIDs} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'TicketIDs must be an array ref!',
         );
         return;
     }
 
-    my @TicketIDs = @{ $Param{TicketIDs} };
-    my $TicketIDString = join ', ', sort @TicketIDs;
+    my $TicketIDString = $Self->_TicketIDStringGet(
+        TicketIDs => $Param{TicketIDs},
+    );
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL => "SELECT DISTINCT(t.type_id), tt.name"
             . " FROM ticket t, ticket_type tt"
-            . " WHERE t.id IN ($TicketIDString) AND t.type_id = tt.id"
+            . " WHERE t.type_id = tt.id"
+            . $TicketIDString
             . " ORDER BY t.type_id DESC",
     );
 
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             $Data{ $Row[0] } = $Row[1];
         }
@@ -376,25 +351,30 @@ sub LockFilterValuesGet {
     }
 
     if ( !IsArrayRefWithData( $Param{TicketIDs} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'TicketIDs must be an array ref!',
         );
         return;
     }
 
-    my @TicketIDs = @{ $Param{TicketIDs} };
-    my $TicketIDString = join ', ', sort @TicketIDs;
+    my $TicketIDString = $Self->_TicketIDStringGet(
+        TicketIDs => $Param{TicketIDs},
+    );
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL => "SELECT DISTINCT(t.ticket_lock_id), tlt.name"
             . " FROM ticket t, ticket_lock_type tlt"
-            . " WHERE t.id IN ($TicketIDString) AND t.ticket_lock_id = tlt.id"
+            . " WHERE ticket_lock_id = tlt.id"
+            . $TicketIDString
             . " ORDER BY t.ticket_lock_id DESC",
     );
 
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             $Data{ $Row[0] } = $Row[1];
         }
@@ -436,25 +416,30 @@ sub ServiceFilterValuesGet {
     }
 
     if ( !IsArrayRefWithData( $Param{TicketIDs} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'TicketIDs must be an array ref!',
         );
         return;
     }
 
-    my @TicketIDs = @{ $Param{TicketIDs} };
-    my $TicketIDString = join ', ', sort @TicketIDs;
+    my $TicketIDString = $Self->_TicketIDStringGet(
+        TicketIDs => $Param{TicketIDs},
+    );
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL => "SELECT DISTINCT(t.service_id), s.name"
             . " FROM ticket t, service s"
-            . " WHERE t.id IN ($TicketIDString) AND t.service_id = s.id"
+            . " WHERE t.service_id = s.id"
+            . $TicketIDString
             . " ORDER BY t.service_id DESC",
     );
 
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             $Data{ $Row[0] } = $Row[1];
         }
@@ -496,25 +481,30 @@ sub SLAFilterValuesGet {
     }
 
     if ( !IsArrayRefWithData( $Param{TicketIDs} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'TicketIDs must be an array ref!',
         );
         return;
     }
 
-    my @TicketIDs = @{ $Param{TicketIDs} };
-    my $TicketIDString = join ', ', sort @TicketIDs;
+    my $TicketIDString = $Self->_TicketIDStringGet(
+        TicketIDs => $Param{TicketIDs},
+    );
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL => "SELECT DISTINCT(t.sla_id), s.name"
             . " FROM ticket t, sla s"
-            . " WHERE t.id IN ($TicketIDString) AND t.sla_id = s.id"
+            . " WHERE t.sla_id = s.id"
+            . $TicketIDString
             . " ORDER BY t.sla_id DESC",
     );
 
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             $Data{ $Row[0] } = $Row[1];
         }
@@ -544,7 +534,7 @@ sub CustomerFilterValuesGet {
 
     # check needed stuff
     if ( !$Param{TicketIDs} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need TicketIDs!',
         );
@@ -552,25 +542,38 @@ sub CustomerFilterValuesGet {
     }
 
     if ( !IsArrayRefWithData( $Param{TicketIDs} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'TicketIDs must be an array ref!',
         );
         return;
     }
 
-    my @TicketIDs = @{ $Param{TicketIDs} };
-    my $TicketIDString = join ', ', sort @TicketIDs;
+    my $TicketIDString = $Self->_TicketIDStringGet(
+        TicketIDs  => $Param{TicketIDs},
+        IncludeAdd => 0,
+    );
 
-    return if !$Self->{DBObject}->Prepare(
+    if ( !$TicketIDString ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'TicketIDs condition string is empty!',
+        );
+        return;
+    }
+
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL => "SELECT DISTINCT(t.customer_id)"
             . " FROM ticket t"
-            . " WHERE t.id IN ($TicketIDString)"
+            . " WHERE $TicketIDString"
             . " ORDER BY t.customer_id DESC",
     );
 
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             $Data{ $Row[0] } = $Row[0];
         }
@@ -600,7 +603,7 @@ sub CustomerUserIDFilterValuesGet {
 
     # check needed stuff
     if ( !$Param{TicketIDs} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need TicketIDs!',
         );
@@ -608,25 +611,38 @@ sub CustomerUserIDFilterValuesGet {
     }
 
     if ( !IsArrayRefWithData( $Param{TicketIDs} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'TicketIDs must be an array ref!',
         );
         return;
     }
 
-    my @TicketIDs = @{ $Param{TicketIDs} };
-    my $TicketIDString = join ', ', sort @TicketIDs;
+    my $TicketIDString = $Self->_TicketIDStringGet(
+        TicketIDs  => $Param{TicketIDs},
+        IncludeAdd => 0,
+    );
 
-    return if !$Self->{DBObject}->Prepare(
+    if ( !$TicketIDString ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'TicketIDs condition string is empty!',
+        );
+        return;
+    }
+
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL => "SELECT DISTINCT(t.customer_user_id)"
             . " FROM ticket t"
-            . " WHERE t.id IN ($TicketIDString)"
+            . " WHERE $TicketIDString"
             . " ORDER BY t.customer_user_id DESC",
     );
 
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             $Data{ $Row[0] } = $Row[0];
         }
@@ -668,35 +684,50 @@ sub OwnerFilterValuesGet {
     }
 
     if ( !IsArrayRefWithData( $Param{TicketIDs} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'TicketIDs must be an array ref!',
         );
         return;
     }
 
-    my @TicketIDs = @{ $Param{TicketIDs} };
-    my $TicketIDString = join ', ', sort @TicketIDs;
+    my $TicketIDString = $Self->_TicketIDStringGet(
+        TicketIDs  => $Param{TicketIDs},
+        IncludeAdd => 0,
+    );
 
-    return if !$Self->{DBObject}->Prepare(
+    if ( !$TicketIDString ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'TicketIDs condition string is empty!',
+        );
+        return;
+    }
+
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL => "SELECT DISTINCT(t.user_id)"
             . " FROM ticket t"
-            . " WHERE t.id IN ($TicketIDString)"
+            . " WHERE $TicketIDString"
             . " ORDER BY t.user_id DESC",
     );
 
     my @UserList;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             push @UserList, $Row[0];
         }
     }
 
-    my %Data;
+    # get user object
+    my $UserObject = $Kernel::OM->Get('Kernel::System::User');
 
+    my %Data;
     if ( scalar @UserList > 0 ) {
         for my $UserID (@UserList) {
-            my %User = $Self->{UserObject}->GetUserData(
+            my %User = $UserObject->GetUserData(
                 UserID => $UserID,
             );
             if (%User) {
@@ -741,34 +772,50 @@ sub ResponsibleFilterValuesGet {
     }
 
     if ( !IsArrayRefWithData( $Param{TicketIDs} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'TicketIDs must be an array ref!',
         );
         return;
     }
 
-    my @TicketIDs = @{ $Param{TicketIDs} };
-    my $TicketIDString = join ', ', sort @TicketIDs;
+    my $TicketIDString = $Self->_TicketIDStringGet(
+        TicketIDs  => $Param{TicketIDs},
+        IncludeAdd => 0,
+    );
 
-    return if !$Self->{DBObject}->Prepare(
+    if ( !$TicketIDString ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'TicketIDs condition string is empty!',
+        );
+        return;
+    }
+
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL => "SELECT DISTINCT(t.responsible_user_id)"
             . " FROM ticket t"
-            . " WHERE t.id IN ($TicketIDString)"
+            . " WHERE $TicketIDString"
             . " ORDER BY t.responsible_user_id DESC",
     );
 
     my @UserList;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             push @UserList, $Row[0];
         }
     }
 
+    # get user object
+    my $UserObject = $Kernel::OM->Get('Kernel::System::User');
+
     my %Data;
     if ( scalar @UserList > 0 ) {
         for my $UserID (@UserList) {
-            my %User = $Self->{UserObject}->GetUserData(
+            my %User = $UserObject->GetUserData(
                 UserID => $UserID,
             );
             if (%User) {
@@ -807,7 +854,7 @@ sub DynamicFieldFilterValuesGet {
     for my $Needed (qw(TicketIDs ValueType FieldID)) {
 
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Needed!",
             );
@@ -815,17 +862,19 @@ sub DynamicFieldFilterValuesGet {
         }
     }
 
+    my $TicketIDString = $Self->_TicketIDStringGet(
+        TicketIDs  => $Param{TicketIDs},
+        ColumnName => 'object_id',
+    );
+
     if ( !IsArrayRefWithData( $Param{TicketIDs} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'TicketIDs must be an array ref!',
         );
         return;
     }
 
-    my @TicketIDs = @{ $Param{TicketIDs} };
-    my $TicketIDString = join ', ', sort @TicketIDs;
-
     my $ValueType = 'value_text';
     if ( $Param{ValueType} && $Param{ValueType} eq 'DateTime' ) {
         $ValueType = 'value_date';
@@ -834,18 +883,21 @@ sub DynamicFieldFilterValuesGet {
         $ValueType = 'value_int';
     }
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL =>
             "SELECT DISTINCT($ValueType)"
             . ' FROM dynamic_field_value'
             . ' WHERE field_id = ?'
-            . " AND object_id IN ($TicketIDString)"
+            . $TicketIDString
             . " ORDER BY $ValueType DESC",
         Bind => [ \$Param{FieldID} ],
     );
 
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
 
         # check if the value is already stored
         if (
@@ -873,13 +925,35 @@ sub DynamicFieldFilterValuesGet {
     return \%Data;
 }
 
+=begin Internal:
+
+=item _GeneralDataGet()
+
+get data list
+
+    my $Values = $ColumnFilterObject->_GeneralDataGet(
+            ModuleName   => 'Kernel::System::Object',
+            FunctionName => 'FunctionNameList',
+            UserID       => $Param{UserID},
+    );
+
+    returns
+
+    $Values = {
+        1 => 'ValueA',
+        2 => 'ValueB',
+        3 => 'ValueC'
+    };
+
+=cut
+
 sub _GeneralDataGet {
     my ( $Self, %Param ) = @_;
 
     # check needed stuff
     for my $Needed (qw(ModuleName FunctionName UserID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Needed!",
             );
@@ -893,8 +967,8 @@ sub _GeneralDataGet {
     my $BackendModule = $Param{ModuleName};
 
     # check if backend field exists
-    if ( !$Self->{MainObject}->Require($BackendModule) ) {
-        $Self->{LogObject}->Log(
+    if ( !$Kernel::OM->Get('Kernel::System::Main')->Require($BackendModule) ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Can't load backend module $BackendModule!",
         );
@@ -905,7 +979,7 @@ sub _GeneralDataGet {
     my $BackendObject = $BackendModule->new( %{$Self} );
 
     if ( !$BackendObject ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Couldn't create a backend object for $BackendModule!",
         );
@@ -913,7 +987,7 @@ sub _GeneralDataGet {
     }
 
     if ( ref $BackendObject ne $BackendModule ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Backend object for $BackendModule was not created successfuly!",
         );
@@ -922,13 +996,68 @@ sub _GeneralDataGet {
 
     # get data list
     my %DataList = $BackendObject->$FuctionName(
-        Valid  => 0,
+        Valid  => 1,
         UserID => $Param{UserID},
     );
 
     return \%DataList;
 }
 
+sub _TicketIDStringGet {
+    my ( $Self, %Param ) = @_;
+
+    $Param{IncludeAdd} = 1 if !defined $Param{IncludeAdd};
+
+    my $ColumnName = $Param{ColumnName} || 't.id';
+
+    if ( !$Param{TicketIDs} || ref $Param{TicketIDs} ne 'ARRAY' || !@{ $Param{TicketIDs} } ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "Need TicketIDs.",
+        );
+        return;
+    }
+
+    # sort ids to cache the SQL query
+    my @SortedIDs = sort { $a <=> $b } @{ $Param{TicketIDs} };
+
+    # Error out if some values were not integers.
+    @SortedIDs = map { $Kernel::OM->Get('Kernel::System::DB')->Quote( $_, 'Integer' ) } @SortedIDs;
+    return if scalar @SortedIDs != scalar @{ $Param{TicketIDs} };
+
+    my $TicketIDString = '';
+
+    # split IN statement with more than 900 elements in more statements bombined with OR
+    # because Oracle doesn't support more than 1000 elements in one IN statement.
+    my @SQLStrings;
+    while ( scalar @SortedIDs ) {
+
+        # remove section in the array
+        my @SortedIDsPart = splice @SortedIDs, 0, 900;
+
+        # link together IDs
+        my $IDString = join ', ', @SortedIDsPart;
+
+        # add new statement
+        push @SQLStrings, " $ColumnName IN ($IDString) ";
+    }
+
+    my $SQLString = join ' OR ', @SQLStrings;
+
+    if ( $Param{IncludeAdd} ) {
+        $TicketIDString .= ' AND ( ' . $SQLString . ' ) ';
+    }
+    else {
+        $TicketIDString = $SQLString
+    }
+
+    return $TicketIDString;
+}
+
+1;
+
+=end Internal:
+
 =back
 
 =head1 TERMS AND CONDITIONS
@@ -940,5 +1069,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-1;
